@@ -42,9 +42,10 @@ import configparser
 import datetime
 import gettext
 import os
-import re
+import platform
 import sys
 import tempfile
+from PIL import Image, ImageGrab
 
 # my modules
 import convert
@@ -57,13 +58,10 @@ import mswindows
 import preview
 import version
 
-if mswindows.windows() == 1:
-    from PIL import ImageGrab
-
 # Start logging
 log.write_log('Start', "M", "w", 1)
 
-# set locale for Windows
+# set locale and clipboard for Windows
 if mswindows.windows() == 1:
     import locale
     if os.getenv('LANG') is None:
@@ -98,10 +96,9 @@ preview_size_list = (300, 350, 400, 450, 500, 550, 600, 650, 700, 800, 900, 1000
 ##########################
 
 
-def print_command(cmd, cmd_magick):
+def print_command(cmd):
     """ print command in custom window """
     t_custom.insert(END, cmd + " ")
-    # co_custom_command.current(magick_commands.index(cmd_magick))
 
 
 def convert_custom_clear():
@@ -269,18 +266,18 @@ def apply_all_convert(out_file, write_command):
     if text_separate == 0:
         cmd = cmd + " " + cmd_text
         if write_command == 1:
-            print_command(cmd, cmd_magick)
+            print_command(cmd)
         result1 = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
         result2 = "OK"
     else:
         # because text gravity which makes problem with crop gravity
         # we have to force second run of conversion
         if write_command == 1:
-            print_command(cmd, cmd_magick)
+            print_command(cmd)
         result1 = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
         cmd_magick = GM_or_IM + "mogrify"
         if write_command == 1:
-            print_command(cmd_text, cmd_magick)
+            print_command(cmd_text)
         result2 = magick.magick(cmd_text, "", out_file, cmd_magick)
 
     if img_logo_on.get() == 1:
@@ -298,7 +295,7 @@ def apply_all_convert(out_file, write_command):
         cmd = cmd1 + cmd2
         cmd_magick = GM_or_IM + "composite"
         if write_command == 1:
-            print_command(cmd, cmd_magick)
+            print_command(cmd)
 
         result3 = magick.magick(cmd, "", out_file, cmd_magick)
     else:
@@ -377,7 +374,7 @@ def convert_custom_button():
                                  work_dir.get(),
                                  co_apply_type.get())
     cmd = t_custom.get('1.0', 'end-1c')
-    cmd_magick = GM_or_IM + co_custom_command.get()
+    cmd_magick = GM_or_IM + "convert"
     result = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
     if result == "OK":
         preview_new(out_file)
@@ -396,7 +393,7 @@ def convert_contrast_button():
                                    e1_contrast.get(),
                                    e2_contrast.get())
     cmd_magick = GM_or_IM + "convert"
-    print_command(cmd, cmd_magick)
+    print_command(cmd)
     result = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
     if result == "OK":
         preview_new(out_file)
@@ -412,7 +409,7 @@ def convert_bw_button():
                                  co_apply_type.get())
     cmd = convert.convert_bw(img_bw.get(), e_bw_sepia.get())
     cmd_magick = GM_or_IM + "convert"
-    print_command(cmd, cmd_magick)
+    print_command(cmd)
     result = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
     if result == "OK":
         preview_new(out_file)
@@ -429,7 +426,7 @@ def convert_normalize_button():
     cmd = convert.convert_normalize(img_normalize.get(),
                                     co_normalize_channel.get())
     cmd_magick = GM_or_IM + "convert"
-    print_command(cmd, cmd_magick)
+    print_command(cmd)
     result = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
     if result == "OK":
         preview_new(out_file)
@@ -445,7 +442,7 @@ def convert_rotate_button():
                                  co_apply_type.get())
     cmd = convert.convert_rotate(img_rotate.get())
     cmd_magick = GM_or_IM + "convert"
-    print_command(cmd, cmd_magick)
+    print_command(cmd)
     result = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
     if result == "OK":
         preview_new(out_file)
@@ -468,7 +465,7 @@ def convert_resize_button():
                                               work_sub_dir.get()),
                                  co_apply_type.get())
     cmd_magick = GM_or_IM + "convert"
-    print_command(cmd, cmd_magick)
+    print_command(cmd)
     result = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
     if result == "OK":
         preview_new(out_file)
@@ -487,7 +484,7 @@ def convert_border_button():
                                  img_border_color.get(),
                                  img_border_on.get())
     cmd_magick = GM_or_IM + "convert"
-    print_command(cmd, cmd_magick)
+    print_command(cmd)
     result = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
     if result == "OK":
         preview_new(out_file)
@@ -505,7 +502,7 @@ def convert_crop_button():
                                img_crop_gravity.get(),
                                convert_crop_entries())
     cmd_magick = GM_or_IM + "convert"
-    print_command(cmd, cmd_magick)
+    print_command(cmd)
     result = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
     if result == "OK":
         preview_new(out_file)
@@ -527,7 +524,7 @@ def convert_logo_button():
           + " " + common.spacja(file_logo_path.get()) \
           + " " + common.spacja(file_in_path.get()) + " "
     cmd_magick = GM_or_IM + "composite"
-    print_command(cmd, cmd_magick)
+    print_command(cmd)
     result = magick.magick(cmd, "", out_file, cmd_magick)
     if result == "OK":
         preview_new(out_file)
@@ -543,7 +540,7 @@ def convert_text_button():
                                  co_apply_type.get())
     cmd = convert.convert_text(convert_text_entries())
     cmd_magick = GM_or_IM + "convert"
-    print_command(cmd, cmd_magick)
+    print_command(cmd)
     result = magick.magick(cmd, file_in_path.get(), out_file, cmd_magick)
     if result == "OK":
         preview_new(out_file)
@@ -575,7 +572,10 @@ def convert_text_entries():
     dict_return['text'] = e_text.get()
     dict_return['dx'] = e_text_x.get()
     dict_return['dy'] = e_text_y.get()
-    dict_return['gravitation'] = img_text_gravity.get()
+    if img_text_gravity_onoff.get():
+        dict_return['gravitation'] = img_text_gravity.get()
+    else:
+        dict_return['gravitation'] = "0"
     if mswindows.windows() == 1:
         dict_return['font'] = img_text_font_dict[img_text_font.get()]
     else:
@@ -601,35 +601,37 @@ def font_selected(event):
 
 def crop_read():
     """ Wczytanie rozmiarów z obrazka do wycinka """
-    img = magick.get_image_size(file_in_path.get(), GM_or_IM)
-    width = img[0]
-    height = img[1]
+    if file_in_path.get() is not None:
+        if os.path.isfile(file_in_path.get()):
+            image_size_xy = magick.get_image_size(file_in_path.get())
+            width = image_size_xy[0]
+            height = image_size_xy[1]
 
-    e1_crop_1.delete(0, "end")
-    e1_crop_1.insert(0, "0")
-    e2_crop_1.delete(0, "end")
-    e2_crop_1.insert(0, "0")
-    e3_crop_1.delete(0, "end")
-    e3_crop_1.insert(0, width)
-    e4_crop_1.delete(0, "end")
-    e4_crop_1.insert(0, height)
-    e1_crop_2.delete(0, "end")
-    e1_crop_2.insert(0, "0")
-    e2_crop_2.delete(0, "end")
-    e2_crop_2.insert(0, "0")
-    e3_crop_2.delete(0, "end")
-    e3_crop_2.insert(0, width)
-    e4_crop_2.delete(0, "end")
-    e4_crop_2.insert(0, height)
-    e1_crop_3.delete(0, "end")
-    e1_crop_3.insert(0, "0")
-    e2_crop_3.delete(0, "end")
-    e2_crop_3.insert(0, "0")
-    e3_crop_3.delete(0, "end")
-    e3_crop_3.insert(0, width)
-    e4_crop_3.delete(0, "end")
-    e4_crop_3.insert(0, height)
-    img_crop_gravity.set("C")
+            e1_crop_1.delete(0, "end")
+            e1_crop_1.insert(0, "0")
+            e2_crop_1.delete(0, "end")
+            e2_crop_1.insert(0, "0")
+            e3_crop_1.delete(0, "end")
+            e3_crop_1.insert(0, width)
+            e4_crop_1.delete(0, "end")
+            e4_crop_1.insert(0, height)
+            e1_crop_2.delete(0, "end")
+            e1_crop_2.insert(0, "0")
+            e2_crop_2.delete(0, "end")
+            e2_crop_2.insert(0, "0")
+            e3_crop_2.delete(0, "end")
+            e3_crop_2.insert(0, width)
+            e4_crop_2.delete(0, "end")
+            e4_crop_2.insert(0, height)
+            e1_crop_3.delete(0, "end")
+            e1_crop_3.insert(0, "0")
+            e2_crop_3.delete(0, "end")
+            e2_crop_3.insert(0, "0")
+            e3_crop_3.delete(0, "end")
+            e3_crop_3.insert(0, width)
+            e4_crop_3.delete(0, "end")
+            e4_crop_3.insert(0, height)
+            img_crop_gravity.set("C")
 
 
 def open_file_logo():
@@ -684,6 +686,9 @@ def open_file():
         extension_from_file()
         file_in_path.set(result)
         root.title(window_title + file_in_path.get())
+        image = Image.open(file_in_path.get())
+        file_in_width.set(image.width)
+        file_in_height.set(image.height)
         preview_orig()
     else:
         preview_orig_clear()
@@ -813,7 +818,7 @@ def open_screenshot():
 
     filename = now.strftime("%F_%H-%M-%S_%f") + ".png"
     out_file = os.path.join(today_dir, filename)
-    if mswindows.windows() == 1:
+    if mswindows.windows() or mswindows.macos():
         screenshot = ImageGrab.grabclipboard()
         try:
             screenshot.save(out_file, 'PNG')
@@ -895,6 +900,7 @@ def ini_read_wraper():
     img_text_font.set(ini_entries['text_font'])
     img_text_color.set(ini_entries['text_color'])
     img_text_gravity.set(ini_entries['img_text_gravity'])
+    img_text_gravity_onoff.set(ini_entries['img_text_gravity_onoff'])
     img_text_box.set(ini_entries['text_box'])
     img_text_box_color.set(ini_entries['text_box_color'])
     e_text.delete(0, "end")
@@ -1007,6 +1013,7 @@ def ini_save():
     config.set('Text', 'inout', str(img_text_inout.get()))
     config.set('Text', 'text', e_text.get())
     config.set('Text', 'gravity', img_text_gravity.get())
+    config.set('Text', 'gravity_onoff', str(img_text_gravity_onoff.get()))
     config.set('Text', 'font', img_text_font.get())
     config.set('Text', 'size', e_text_size.get())
     config.set('Text', 'color', img_text_color.get())
@@ -1104,15 +1111,16 @@ def win_deleted():
 def mouse_crop_NW(event):
     """ Left-Upper corner """
 
-    if img_crop_on.get() == 1:
-        x_preview = event.x
-        y_preview = event.y
+    x_preview = event.x
+    y_preview = event.y
 
-        xy_max = common.mouse_crop_calculation(file_in_path.get(),
-                                               int(co_preview_selector_orig.get()),
-                                               GM_or_IM)
-        width = int(x_preview*xy_max['x_orig']/xy_max['x_max'])
-        height = int(y_preview*xy_max['y_orig']/xy_max['y_max'])
+    xy_max = common.mouse_crop_calculation(file_in_width.get(),
+                                           file_in_width.get(),
+                                           int(co_preview_selector_orig.get()))
+    width = int(x_preview*xy_max['x_orig']/xy_max['x_max'])
+    height = int(y_preview*xy_max['y_orig']/xy_max['y_max'])
+
+    if img_crop_on.get() == 1:
         e1_crop_1.delete(0, "end")
         e1_crop_1.insert(0, width)
         e2_crop_1.delete(0, "end")
@@ -1120,6 +1128,12 @@ def mouse_crop_NW(event):
 
         preview_orig()
 
+    if img_text_on.get() and not img_text_gravity_onoff.get():
+        e_text_x.delete(0, "end")
+        e_text_x.insert(0, width)
+        e_text_y.delete(0, "end")
+        e_text_y.insert(0, height)
+
 
 def mouse_crop_SE(event):
     """ Right-Lower corner """
@@ -1127,9 +1141,9 @@ def mouse_crop_SE(event):
     if img_crop_on.get() == 1:
         x_preview = event.x
         y_preview = event.y
-        xy_max = common.mouse_crop_calculation(file_in_path.get(),
-                                               int(co_preview_selector_orig.get()),
-                                               GM_or_IM)
+        xy_max = common.mouse_crop_calculation(file_in_width.get(),
+                                               file_in_width.get(),
+                                               int(co_preview_selector_orig.get()))
         width = int(x_preview*xy_max['x_orig']/xy_max['x_max'])
         height = int(y_preview*xy_max['y_orig']/xy_max['y_max'])
         e3_crop_1.delete(0, "end")
@@ -1151,50 +1165,51 @@ def preview_orig():
     and add crop rectangle
     """
     if co_preview_selector_orig.get() != "none":
-        if img_crop_on.get() == 1:
-            # draw crop rectangle on preview
-            xy_max = common.mouse_crop_calculation(file_in_path.get(),
-                                               int(co_preview_selector_orig.get()),
-                                               GM_or_IM)
-            if img_crop.get() == 1:
-                x0 = int(e1_crop_1.get())
-                y0 = int(e2_crop_1.get())
-                x1 = int(e3_crop_1.get())
-                y1 = int(e4_crop_1.get())
-                # do_nothing = 0
-            elif img_crop.get() == 2:
-                x0 = int(e1_crop_2.get())
-                y0 = int(e2_crop_2.get())
-                x1 = x0 + int(e3_crop_2.get())
-                y1 = y0 + int(e4_crop_2.get())
-                # do_nothing = 0
-            elif img_crop.get() == 3:
-                coord_for_crop = (int(e1_crop_3.get()), int(e2_crop_3.get()),
-                              int(e3_crop_3.get()), int(e4_crop_3.get()),
-                              img_crop_gravity.get())
-                coord = convert.convert_preview_crop_gravity(coord_for_crop,
-                                                         xy_max['x_orig'],
-                                                         xy_max['y_orig'])
-                x0 = coord[0]
-                y0 = coord[1]
-                x1 = coord[2]
-                y1 = coord[3]
-                # do_nothing = 0
+        if os.path.isfile(file_in_path.get()):
+            if img_crop_on.get() == 1:
+                # draw crop rectangle on preview
+                xy_max = common.mouse_crop_calculation(file_in_width.get(),
+                                               file_in_width.get(),
+                                               int(co_preview_selector_orig.get()))
+                if img_crop.get() == 1:
+                    x0 = int(e1_crop_1.get())
+                    y0 = int(e2_crop_1.get())
+                    x1 = int(e3_crop_1.get())
+                    y1 = int(e4_crop_1.get())
+                    # do_nothing = 0
+                elif img_crop.get() == 2:
+                    x0 = int(e1_crop_2.get())
+                    y0 = int(e2_crop_2.get())
+                    x1 = x0 + int(e3_crop_2.get())
+                    y1 = y0 + int(e4_crop_2.get())
+                    # do_nothing = 0
+                elif img_crop.get() == 3:
+                    coord_for_crop = (int(e1_crop_3.get()), int(e2_crop_3.get()),
+                                  int(e3_crop_3.get()), int(e4_crop_3.get()),
+                                  img_crop_gravity.get())
+                    coord = convert.convert_preview_crop_gravity(coord_for_crop,
+                                                             xy_max['x_orig'],
+                                                             xy_max['y_orig'])
+                    x0 = coord[0]
+                    y0 = coord[1]
+                    x1 = coord[2]
+                    y1 = coord[3]
+                    # do_nothing = 0
 
-            ratio_X = xy_max['x_max'] / xy_max['x_orig']
-            ratio_Y = xy_max['y_max'] / xy_max['y_orig']
-            x0 = int(x0 * ratio_X)
-            y0 = int(y0 * ratio_Y)
-            x1 = int(x1 * ratio_X)
-            y1 = int(y1 * ratio_Y)
+                ratio_X = xy_max['x_max'] / xy_max['x_orig']
+                ratio_Y = xy_max['y_max'] / xy_max['y_orig']
+                x0 = int(x0 * ratio_X)
+                y0 = int(y0 * ratio_Y)
+                x1 = int(x1 * ratio_X)
+                y1 = int(y1 * ratio_Y)
 
 #            x0y0x1y1 = str(x0) + "," + str(y0) + " " + str(x1) + "," + str(y1)
 #            command = " -fill none  -draw \"stroke '#FFFF00' rectangle " \
 #                + x0y0x1y1 + "\" "
-            crop_rectangle = (x0, y0, x1, y1)
-        else:
- #           command = " "
-            crop_rectangle = (" ")
+                crop_rectangle = (x0, y0, x1, y1)
+            else:
+ #               command = " "
+                crop_rectangle = (" ")
 # it works with every pictures
 #        preview_picture = preview.preview_convert(file_in_path.get(),
 #                                              command,
@@ -1202,29 +1217,29 @@ def preview_orig():
 #                                              GM_or_IM)
 
 # it can has problem with RGBA png/gif files
-        preview_picture = preview.preview_pillow(file_in_path.get(),
-                                              int(co_preview_selector_orig.get()),
-                                              crop_rectangle)
+            preview_picture = preview.preview_pillow(file_in_path.get(),
+                                                  int(co_preview_selector_orig.get()),
+                                                  crop_rectangle)
 
-        try:
-            pi_preview_orig.configure(file=common.spacja(preview_picture['filename']))
-            l_preview_orig_pi.configure(image=pi_preview_orig)
-        except:
-            log.write_log("preview_orig: Cannot load preview", "E")
+            try:
+                pi_preview_orig.configure(file=common.spacja(preview_picture['filename']))
+                l_preview_orig_pi.configure(image=pi_preview_orig)
+            except:
+                log.write_log("preview_orig: Cannot load preview", "E")
 
-        try:
-            l_preview_orig.configure(text=preview_picture['width'] + "x" \
-                                 + preview_picture['height'] \
-                                 + " - " \
-                                 + preview_picture['size'])
-        except:
-            log.write_log("preview_orig: Cannot load image size", "E")
+            try:
+                l_preview_orig.configure(text=preview_picture['width'] + "x" \
+                                     + preview_picture['height'] \
+                                     + " - " \
+                                     + preview_picture['size'])
+            except:
+                log.write_log("preview_orig: Cannot load image size", "E")
 
-        if img_histograms_on.get() == 1:
-            pi_histogram_orig.configure(file=preview.preview_histogram(file_in_path.get(), GM_or_IM))
-            l_histogram_orig.configure(image=pi_histogram_orig)
-    else:
-        preview_orig_clear()
+            if img_histograms_on.get() == 1:
+                pi_histogram_orig.configure(file=preview.preview_histogram(file_in_path.get(), GM_or_IM))
+                l_histogram_orig.configure(image=pi_histogram_orig)
+        else:
+            preview_orig_clear()
 
 
 def preview_logo():
@@ -1377,18 +1392,56 @@ def crop_tool_hide_show():
 
 def text_tool_hide_show():
     """hide not necessary things, or show if the are needed"""
-    if img_text_inout.get() == 0:
-        l_text_xy_l.grid()
-        l_text_xy_x.grid()
-        l_text_xy_y.grid()
-        e_text_x.grid()
-        e_text_y.grid()
-    else:
-        l_text_xy_l.grid_remove()
+    if img_text_inout.get():
+        # Outside
         l_text_xy_x.grid_remove()
         l_text_xy_y.grid_remove()
         e_text_x.grid_remove()
         e_text_y.grid_remove()
+        rb_text_NW.grid()
+        rb_text_N.grid()
+        rb_text_NE.grid()
+        rb_text_W.grid_remove()
+        rb_text_C.grid_remove()
+        rb_text_E.grid_remove()
+        rb_text_SW.grid()
+        rb_text_S.grid()
+        rb_text_SE.grid()
+        cb_text_gravity.grid_remove()
+    else:
+        # Inside
+        l_text_xy_x.grid()
+        l_text_xy_y.grid()
+        e_text_x.grid()
+        e_text_y.grid()
+        cb_text_gravity.grid()
+        if img_text_gravity_onoff.get():
+            # Gravity on
+            rb_text_NW.grid()
+            rb_text_N.grid()
+            rb_text_NE.grid()
+            rb_text_W.grid()
+            rb_text_C.grid()
+            rb_text_E.grid()
+            rb_text_SW.grid()
+            rb_text_S.grid()
+            rb_text_SE.grid()
+            l_text_xy_x.configure(text=_("dx"))
+            l_text_xy_y.configure(text=_("dy"))
+        else:
+            # Gravity off
+            rb_text_NW.grid_remove()
+            rb_text_N.grid_remove()
+            rb_text_NE.grid_remove()
+            rb_text_W.grid_remove()
+            rb_text_C.grid_remove()
+            rb_text_E.grid_remove()
+            rb_text_SW.grid_remove()
+            rb_text_S.grid_remove()
+            rb_text_SE.grid_remove()
+            l_text_xy_x.configure(text=_("x"))
+            l_text_xy_y.configure(text=_("y"))
+
 
 ###############################################################################
 # GUI okno główne
@@ -1429,6 +1482,9 @@ work_sub_dir = StringVar()  # subdir for resized pictures
 work_sub_dir.set("")  # default none
 file_dir_selector = IntVar()
 file_in_path = StringVar()  # fullpath original picture
+file_in_width = IntVar() # width original picture
+file_in_height = IntVar() # height original picture
+file_in_size = IntVar() # size original picture (bytes)
 img_histograms_on = IntVar()
 img_logo_on = IntVar()  # Logo
 file_logo_path = StringVar()  # fullpath logo file
@@ -1437,6 +1493,7 @@ img_resize_on = IntVar()  # Resize
 img_resize = IntVar()  # (1, 2, 3, 4, 5)
 img_text_on = IntVar()  # Text
 img_text_gravity = StringVar()
+img_text_gravity_onoff = IntVar()
 img_text_font = StringVar()
 img_text_font_dict = {}  # dict with available fonts, from fonts()
 img_text_color = StringVar()
@@ -1495,7 +1552,7 @@ b_file_select = ttk.Button(frame_file_select, text=_("File selection"),
 
 b_file_select_screenshot = ttk.Button(frame_file_select, text=_("Screenshot"),
                                  command=open_screenshot)
-if mswindows.windows() == 1:
+if mswindows.windows() or mswindows.macos():
     b_file_select_screenshot.configure(text=_("Clipboard"))
 
 b_file_select_first = ttk.Button(frame_file_select, text=_("First"),
@@ -1694,7 +1751,7 @@ e1_crop_1 = ttk.Entry(f_clickL_crop, width=4,
 e2_crop_1 = ttk.Entry(f_clickL_crop, width=4,
                       validate="key", validatecommand=(validation, '%S'))
 f_clickR_crop = ttk.Frame(frame_crop)
-l_clickR_crop = ttk.Label(f_clickR_crop, text=_("Right lower\ncorner\nClick right"))
+l_clickR_crop = ttk.Label(f_clickR_crop, text=_("Right Lower\ncorner\nClick right"))
 e3_crop_1 = ttk.Entry(f_clickR_crop, width=4,
                       validate="key", validatecommand=(validation, '%S'))
 e4_crop_1 = ttk.Entry(f_clickR_crop, width=4,
@@ -1820,19 +1877,23 @@ cb_text_box = ttk.Checkbutton(frame_text, text=_("Background"),
                               variable=img_text_box,
                               onvalue="1", offvalue="0",
                               command=color_choose_set)
-l_text_xy_l = ttk.Label(frame_text, text=_("Offset"))
+cb_text_gravity = ttk.Checkbutton(frame_text, text=_("Gravity"),
+                              variable=img_text_gravity_onoff,
+                              onvalue="1", offvalue="0",
+                              command=text_tool_hide_show)
+#l_text_xy_l = ttk.Label(frame_text, text=_("Offset"))
 l_text_xy_x = ttk.Label(frame_text, text=_("dx"))
 l_text_xy_y = ttk.Label(frame_text, text=_("dy"))
-e_text_x = ttk.Entry(frame_text, width=3,
+e_text_x = ttk.Entry(frame_text, width=4,
                      validate="key", validatecommand=(validation, '%S'))
-e_text_y = ttk.Entry(frame_text, width=3,
+e_text_y = ttk.Entry(frame_text, width=4,
                      validate="key", validatecommand=(validation, '%S'))
 
 rb_text_in.grid(row=2,  column=1, sticky=W, padx=5, pady=1)
 rb_text_out.grid(row=3, column=1, sticky=W, padx=5, pady=1)
 cb_text_box.grid(row=4, column=1, sticky=W, padx=5, pady=1)
+cb_text_gravity.grid(row=2, column=3, columnspan=2, sticky=W, pady=1)
 
-l_text_xy_l.grid(row=2, column=3, columnspa=2, sticky=W, padx=5, pady=1)
 l_text_xy_x.grid(row=3, column=3, sticky=W, padx=5, pady=1)
 l_text_xy_y.grid(row=3, column=4, sticky=W, padx=5, pady=1)
 e_text_x.grid(row=4, column=3, sticky=(W, N), padx=5, pady=1)
@@ -2125,17 +2186,6 @@ t_custom.pack(expand=1, fill='both', padx=5, pady=5)
 b_custom_run.pack(side='right', padx=5, pady=5)
 b_custom_clear.pack(side='right', padx=5, pady=5)
 
-### temporary off, later will be enabled
-l_custom_command = ttk.Label(frame_custom, text=_("Command:"))
-co_custom_command = ttk.Combobox(frame_custom, width=9,
-                                 values=magick_commands)
-co_custom_command.current(1)
-co_custom_command.configure(state='readonly')
-
-# l_custom_command.grid(row=2, column=1, padx=5, pady=5, sticky=E)
-# co_custom_command.grid(row=2, column=2, padx=5, pady=5, sticky=W)
-
-
 #####################################################
 # Second column
 #####################################################
@@ -2226,7 +2276,10 @@ co_preview_selector_orig.bind("<<ComboboxSelected>>", preview_orig_refresh)
 co_preview_selector_new.bind("<<ComboboxSelected>>", preview_new_refresh)
 co_text_font.bind("<<ComboboxSelected>>", font_selected)
 l_preview_orig_pi.bind("<Button-1>", mouse_crop_NW)
-l_preview_orig_pi.bind("<Button-3>", mouse_crop_SE)
+if mswindows.macos():
+    l_preview_orig_pi.bind("<Button-2>", mouse_crop_SE)
+else:
+    l_preview_orig_pi.bind("<Button-3>", mouse_crop_SE)
 root.bind("<F1>", help_info)
 root.protocol("WM_DELETE_WINDOW", win_deleted)
 
@@ -2242,23 +2295,23 @@ root.bind("<End>", open_file_last_key)
 # check if [Image|Graphics]Magick is available
 GM_or_IM_data = magick.check_magick()
 GM_or_IM = GM_or_IM_data[0]
-GM_or_IM_name = GM_or_IM_data[1]
-GM_or_IM_version = magick.get_magick_version(GM_or_IM)
-Python_version = re.findall('^\\d[.]\\d+[.]\\d+', sys.version)
-window_title = version.__author__ + " : " + version.__name__ + " : " + version.__version__ + " : " + GM_or_IM_version + " : " + Python_version[0] + " | "
+GM_or_IM_version = GM_or_IM_data[1]
+Python_version = 'Py:' + platform.python_version()
+window_title = version.__author__ + " : " + version.__appname__ + ": " + version.__version__ + " : " + GM_or_IM_version + " : " + Python_version + " | "
 root.title(window_title)
 if GM_or_IM is not None:
     img_text_font_dict = fonts()    # Reading available fonts
     ini_read_wraper()  # Loading from config file
     tools_set(0)
-    crop_tool_hide_show()
     color_choose_set()
     text_tool_hide_show()
     l_border.configure(bg=img_border_color.get())
     if os.path.isfile(file_in_path.get()):
         root.title(window_title + file_in_path.get())
-        # Load preview picture
-#        preview_orig()
+        image_size =  magick.get_image_size(file_in_path.get())
+        file_in_width.set(image_size[0])
+        file_in_height.set(image_size[1])
+        crop_tool_hide_show()
     if img_logo_on.get() == 1:
         if os.path.isfile(file_logo_path.get()):
             # Load preview logo
