@@ -40,6 +40,7 @@ import os
 import re
 import shutil
 import tempfile
+from PIL import Image
 
 import common
 import log
@@ -138,6 +139,7 @@ def magick_command(command):
 def get_fonts_dict(gm_or_im):
     """ get available font dict (name: path) from imagemagick """
 
+    fonts_dict = {}
     file_font = os.path.join(tempfile.gettempdir(),
                              "fotokilof_" + os.getlogin() + "_fonts_list")
     command = " -list font > "
@@ -216,7 +218,7 @@ def get_magick_version(gm_or_im):
 
 def check_magick():
     """
-    What is available: ImageMagick, Graphick Magick or none
+    What is available: ImageMagick, Graphick Magick or none, and version
     """
     if mswindows.windows() == 1:
         suffix = ".exe"
@@ -225,17 +227,18 @@ def check_magick():
     if check_imagemagick(suffix) is not None:
         version = "IM"
         if mswindows.windows() == 1:
-            result = "magick "
+            result_gm = "magick "
         else:
-            result = ""
+            result_gm = ""
     elif check_graphicsmagick(suffix) is not None:
         version = "GM"
-        result = "gm "
+        result_gm = "gm "
     else:
         version = ""
-        result = None
+        result_gm = None
 
-    return (result, version)
+    version = version + ':' + get_magick_version(result_gm)
+    return (result_gm, version)
 
 
 def check_imagemagick(suffix):
@@ -275,7 +278,7 @@ def check_graphicsmagick(suffix):
     return result
 
 
-def get_image_size(file_in, gm_or_im):
+def get_image_size(file_in):
     """
     identify width and height of picture
     input: file name
@@ -284,29 +287,37 @@ def get_image_size(file_in, gm_or_im):
 
     width = 1
     height = 1
-    size = ""
-    file_info = common.spacja(os.path.join(tempfile.gettempdir(),
-                                           "fotokilof_" + os.getlogin() \
-                                           + "_image_info"))
 
-    command = ' -format "%w\\n%h\\n%b" '
-    command = command + common.spacja(file_in) + ' > '
-    result = magick(command, "", file_info, gm_or_im + "identify")
-    if result is not None:
-        try:
-            file = open(file_info, "r")
-        except:
-            log.write_log("get_image_size: cannot read file_info", "W")
-        else:
-            width = int(file.readline())
-            height = int(file.readline())
-            size = file.readline()
-            file.close()
-            try:
-                os.remove(file_info)
-            except:
-                log.write_log("get_image_size: cannot remove image_info", "W")
-    return (width, height, size)
+    if file_in is not None:
+        if os.path.isfile(file_in):
+            # for JPG, PNG, TIF
+            image = Image.open(file_in)
+            width = image.width
+            height = image.height
+
+# For others file types use identify
+#    file_info = common.spacja(os.path.join(tempfile.gettempdir(),
+#                                           "fotokilof_" + os.getlogin() \
+#                                           + "_image_info"))
+
+#    command = ' -format "%w\\n%h\\n%b" '
+#    command = command + common.spacja(file_in) + ' > '
+#    result = magick(command, "", file_info, GM_or_IM + "identify")
+#    if result is not None:
+#        try:
+#            file = open(file_info, "r")
+#        except:
+#            log.write_log("get_image_size: cannot read file_info", "W")
+#        else:
+#            width = int(file.readline())
+#            height = int(file.readline())
+#            size = file.readline()
+#            file.close()
+#            try:
+#                os.remove(file_info)
+#            except:
+#                log.write_log("get_image_size: cannot remove image_info", "W")
+    return (width, height)
 
 
 def display_image(file_in, gm_or_im):
